pub struct SessionPermissions {
pub mode: PermissionMode,
pub allow: Vec<String>,
pub deny: Vec<String>,
pub tool_limits: HashMap<String, SessionToolLimits>,
}Expand description
Session-level permission configuration.
This is a simplified, serializable version for session storage.
For runtime permission checking with rule patterns, use crate::permissions::PermissionPolicy.
Fields
mode: PermissionModeallow: Vec<String>deny: Vec<String>tool_limits: HashMap<String, SessionToolLimits>Trait Implementations
Sourceimpl Clone for SessionPermissions
impl Clone for SessionPermissions
Sourcefn clone(&self) -> SessionPermissions
fn clone(&self) -> SessionPermissions
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionPermissions
impl Debug for SessionPermissions
Sourceimpl Default for SessionPermissions
impl Default for SessionPermissions
Sourcefn default() -> SessionPermissions
fn default() -> SessionPermissions
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionPermissions
impl<'de> Deserialize<'de> for SessionPermissions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more